==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragen/v20170401/BestandenlijstOpvragenType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragen.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401.AfgifteSelectieCriteriaType;


/**
 * Het opvragen van een bestandenlijst met grote
 *         bestanden inclusief afgifte gegevens. De lijst zal alleen die
 *         afgiftes gaan bevatten die voldoen aan de gebruikte
 *         selectiegegevens. Indien er geen afgiftes voldoen aan deze
 *         selectie gegevens, dan zal er geen bestandenlijst aanwezig zijn
 *         in het resultaat. 
 * 
 * &lt;p&gt;Java class for BestandenlijstOpvragenType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="BestandenlijstOpvragenType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401}AfgifteSelectieCriteria"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenlijstOpvragenType", propOrder = {
    "afgifteSelectieCriteria"
})
public class BestandenlijstOpvragenType {

    @XmlElement(name = "AfgifteSelectieCriteria", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", required = true)
    protected AfgifteSelectieCriteriaType afgifteSelectieCriteria;

    /**
     * Gets the value of the afgifteSelectieCriteria property.
     * 
     * @return
     *     possible object is
     *     {@link AfgifteSelectieCriteriaType }
     *     
     */
    public AfgifteSelectieCriteriaType getAfgifteSelectieCriteria() {
        return afgifteSelectieCriteria;
    }

    /**
     * Sets the value of the afgifteSelectieCriteria property.
     * 
     * @param value
     *     allowed object is
     *     {@link AfgifteSelectieCriteriaType }
     *     
     */
    public void setAfgifteSelectieCriteria(AfgifteSelectieCriteriaType value) {
        this.afgifteSelectieCriteria = value;
    }

}

==> kadaster-gds2-2.7-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragen/v20170401/BestandenlijstOpvragenType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragen.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401.AfgifteSelectieCriteriaType;


/**
 * Het opvragen van een bestandenlijst met grote
 *         bestanden inclusief afgifte gegevens. De lijst zal alleen die
 *         afgiftes gaan bevatten die voldoen aan de gebruikte
 *         selectiegegevens. Indien er geen afgiftes voldoen aan deze
 *         selectie gegevens, dan zal er geen bestandenlijst aanwezig zijn
 *         in het resultaat. 
 * 
 * <p>Java class for BestandenlijstOpvragenType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandenlijstOpvragenType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401}AfgifteSelectieCriteria"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenlijstOpvragenType", propOrder = {
    "afgifteSelectieCriteria"
})
public class BestandenlijstOpvragenType {

    @XmlElement(name = "AfgifteSelectieCriteria", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", required = true)
    protected AfgifteSelectieCriteriaType afgifteSelectieCriteria;

    /**
     * Gets the value of the afgifteSelectieCriteria property.
     * 
     * @return
     *     possible object is
     *     {@link AfgifteSelectieCriteriaType }
     *     
     */
    public AfgifteSelectieCriteriaType getAfgifteSelectieCriteria() {
        return afgifteSelectieCriteria;
    }

    /**
     * Sets the value of the afgifteSelectieCriteria property.
     * 
     * @param value
     *     allowed object is
     *     {@link AfgifteSelectieCriteriaType }
     *     
     */
    public void setAfgifteSelectieCriteria(AfgifteSelectieCriteriaType value) {
        this.afgifteSelectieCriteria = value;
    }

}
